@@ -46,9 +46,10 @@ import org.drools.workbench.screens.guided.dtable.client.widget.table.keyboard.S
 import org.drools.workbench.screens.guided.dtable.client.widget.table.keyboard.SelectionPaste;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.popovers.ColumnHeaderPopOver;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.popovers.ColumnHeaderPopOverHandler;
-import org.drools.workbench.screens.guided.dtable.client.wizard.column.NewGuidedDecisionTableColumnWizard;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.themes.GuidedDecisionTableRenderer;
 import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorContent;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
+import org.kie.workbench.common.services.verifier.reporting.client.panel.AnalysisReportScreen;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.ext.wires.core.grids.client.model.Bounds;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
@@ -76,28 +77,26 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
 
     private final ColumnHeaderPopOver columnHeaderPopOver;
 
-    private final ManagedInstance<NewGuidedDecisionTableColumnWizard> wizardManagedInstance;
-
     private GuidedDecisionTableView.Presenter activeDecisionTable = null;
 
     private Set<GuidedDecisionTableView.Presenter> availableDecisionTables = new HashSet<>();
 
     private Set<HandlerRegistration> handlerRegistrations = new HashSet<>();
 
+    private AnalysisReportScreen analysisReportScreen;
+
     @Inject
     public GuidedDecisionTableModellerPresenter(final GuidedDecisionTableModellerView view,
                                                 final ManagedInstance<GuidedDecisionTableView.Presenter> dtPresenterProvider,
                                                 final GuidedDecisionTableModellerContextMenuSupport contextMenuSupport,
                                                 final Event<RadarMenuBuilder.UpdateRadarEvent> updateRadarEvent,
                                                 final Event<DecisionTablePinnedEvent> pinnedEvent,
-                                                final ColumnHeaderPopOver columnHeaderPopOver,
-                                                final ManagedInstance<NewGuidedDecisionTableColumnWizard> wizardManagedInstance) {
+                                                final ColumnHeaderPopOver columnHeaderPopOver) {
         this.view = view;
         this.dtPresenterProvider = dtPresenterProvider;
         this.updateRadarEvent = updateRadarEvent;
         this.pinnedEvent = pinnedEvent;
         this.columnHeaderPopOver = columnHeaderPopOver;
-        this.wizardManagedInstance = wizardManagedInstance;
 
         this.view.init(this);
 
@@ -167,6 +166,7 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
         //Set content of new Presenter
         dtPresenter.setContent(path,
                                placeRequest,
+                               analysisReportScreen,
                                content,
                                this,
                                isReadOnly);
@@ -390,7 +390,17 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
     public void onViewPinned(final boolean isPinned) {
         pinnedEvent.fire(new DecisionTablePinnedEvent(this,
                                                       isPinned));
-        view.setPinnedModeIndicatorVisibility(isPinned);
+
+        view.setPinnedModeIndicatorVisibility(isPinned,
+                                              getHeaderCaptionWidth());
+    }
+
+    private double getHeaderCaptionWidth() {
+        if (getActiveDecisionTable().get().getView().getRenderer() instanceof GuidedDecisionTableRenderer) {
+            return ((GuidedDecisionTableRenderer) getActiveDecisionTable().get().getView().getRenderer()).getHeaderCaptionWidth() + 10;
+        } else {
+            return 0;
+        }
     }
 
     @Override
@@ -405,4 +415,9 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
         }
         getView().getGridLayerView().refreshGridWidgetConnectors();
     }
+
+    @Override
+    public void analysisReportScreen(final AnalysisReportScreen analysisReportScreen) {
+        this.analysisReportScreen = analysisReportScreen;
+    }
 }
