@@ -3,15 +3,16 @@
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
- * 
- *      http://www.apache.org/licenses/LICENSE-2.0
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
-*/
+ */
 
 package org.drools.workbench.screens.guided.dtable.client.widget.table.utilities;
 
@@ -21,7 +22,6 @@ import java.util.function.Function;
 import java.util.stream.Stream;
 
 import com.google.gwt.i18n.shared.DateTimeFormat;
-import org.drools.workbench.models.datamodel.oracle.DataType;
 import org.drools.workbench.models.datamodel.rule.BaseSingleFieldConstraint;
 import org.drools.workbench.models.guided.dtable.shared.model.ActionInsertFactCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.ActionSetFieldCol52;
@@ -29,12 +29,14 @@ import org.drools.workbench.models.guided.dtable.shared.model.AttributeCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.BaseColumn;
 import org.drools.workbench.models.guided.dtable.shared.model.ConditionCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
+import org.drools.workbench.models.guided.dtable.shared.util.ColumnUtilitiesBase;
 import org.drools.workbench.screens.guided.dtable.client.resources.GuidedDecisionTableResources;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.control.ColumnLabelWidget;
-import org.drools.workbench.services.verifier.plugin.client.builders.ColumnUtilitiesBase;
+import org.kie.soup.commons.util.ListSplitter;
+import org.kie.soup.commons.validation.PortablePreconditions;
+import org.kie.soup.project.datamodel.oracle.DataType;
 import org.kie.workbench.common.services.shared.preferences.ApplicationPreferences;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
-import org.uberfire.commons.validation.PortablePreconditions;
 
 /**
  * Utilities for Columns
@@ -141,15 +143,24 @@ public class ColumnUtilities
     private String[] parseValueList(String fieldType,
                                     String valueList) {
 
-        final String[] values = valueList.split(",");
+        final String[] values = ListSplitter.split("'", true, valueList);
 
-        return Stream.of(values).filter(value -> isValueValidForType(value,
+        return Stream.of(values).filter(value -> isValueValidForType(parseActualValue(value),
                                                                      convertToTypeSafeType(fieldType)))
                 .toArray(String[]::new);
     }
 
+    private String parseActualValue(final String value) {
+        if (value != null && value.indexOf("=") > 0) {
+            return value.substring(0, value.indexOf("="));
+        } else {
+            return value;
+        }
+    }
+
     private boolean isValueValidForType(String value,
                                         DataType.DataTypes type) {
+
         switch (type) {
             case STRING:
                 return true;
