@@ -34,6 +34,7 @@ import org.drools.verifier.api.reporting.Issue;
 import org.drools.verifier.api.reporting.Severity;
 import org.drools.workbench.models.datamodel.rule.ActionFieldValue;
 import org.drools.workbench.models.datamodel.rule.ActionInsertFact;
+import org.drools.workbench.models.datamodel.rule.Attribute;
 import org.drools.workbench.models.datamodel.rule.FieldNatureType;
 import org.drools.workbench.models.guided.dtable.shared.model.ActionInsertFactCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.AttributeCol52;
@@ -57,7 +58,6 @@ import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer.VetoException;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.utilities.DependentEnumsUtilities;
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableLinkManager.LinkFoundCallback;
-import org.drools.workbench.screens.guided.rule.client.widget.attribute.RuleAttributeWidget;
 import org.jboss.errai.security.shared.api.identity.User;
 import org.junit.Before;
 import org.junit.Test;
@@ -474,11 +474,11 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         linkTables();
 
         verify(uiModel1Columns,
-               atLeast(1)).get(eq(2));
+               atLeast(1)).get(eq(3));
         verify(uiModel2Columns,
-               atLeast(1)).get(eq(2));
+               atLeast(1)).get(eq(3));
         verify(uiModel3Columns,
-               atLeast(1)).get(eq(2));
+               atLeast(1)).get(eq(3));
 
         verify(uiModel2MockColumn).setLink(eq(uiModel1MockColumn));
         verify(uiModel3MockColumn).setLink(eq(uiModel1MockColumn));
@@ -622,6 +622,16 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         verify(uiModel3MockColumn).setLink(eq(uiModel2MockColumn));
     }
 
+    @Test
+    public void setRuleNameColumnVisibility() {
+
+        dtPresenter.setShowRuleName(true);
+        assertFalse(model.getRuleNameColumn().isHideColumn());
+
+        dtPresenter.setShowRuleName(false);
+        assertTrue(model.getRuleNameColumn().isHideColumn());
+    }
+
     @Test
     @SuppressWarnings("unchecked")
     public void testNoLink() throws Exception {
@@ -756,8 +766,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
 
         verify(decisionTableSelectedEvent,
                times(1)).fire(any(DecisionTableSelectedEvent.class));
-        verify(lockManager,
-               times(1)).acquireLock();
+
+        // 3 rows created during the setup + 1 select action
+        verify(lockManager, times(4)).acquireLock();
     }
 
     @Test
@@ -796,7 +807,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     @Test
     public void hasColumnDefinitionsWithAttributeColumn() {
         final AttributeCol52 attribute = new AttributeCol52();
-        attribute.setAttribute("attribute");
+        attribute.setAttribute(Attribute.SALIENCE.getAttributeName());
 
         dtPresenter.getModel().getAttributeCols().add(attribute);
 
@@ -900,7 +911,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     @Test
     public void getValueListLookups() {
         final AttributeCol52 attribute = new AttributeCol52();
-        attribute.setAttribute(RuleAttributeWidget.ENABLED_ATTR);
+        attribute.setAttribute(Attribute.ENABLED.getAttributeName());
 
         final Map<String, String> valueList = dtPresenter.getValueListLookups(attribute);
 
@@ -1094,6 +1105,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
                times(1)).appendRow();
         verify(modellerPresenter,
                times(1)).updateLinks();
+        // 3 rows created during the setup + 1 row created on this test
+        verify(lockManager,
+               times(4)).acquireLock();
     }
 
     @Test
@@ -1139,7 +1153,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     @Test
     public void deleteAttributeColumn() throws Exception {
         final AttributeCol52 column = new AttributeCol52();
-        column.setAttribute("salience");
+        column.setAttribute(Attribute.SALIENCE.getAttributeName());
         dtPresenter.appendColumn(column);
         reset(modellerPresenter);
 
@@ -1251,6 +1265,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
 
         verify(clipboard,
                times(1)).setData(any(Set.class));
+        // 3 rows created during the setup + 1 selected cell on this test
+        verify(lockManager,
+               times(4)).acquireLock();
     }
 
     @Test
@@ -1272,6 +1289,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
 
         verify(clipboard,
                times(1)).setData(any(Set.class));
+        // 3 rows created during the setup + 1 selected cell on this test
+        verify(lockManager,
+               times(4)).acquireLock();
     }
 
     @Test
@@ -1295,6 +1315,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
 
         verify(clipboard,
                times(1)).getData();
+        // 3 rows created during the setup + 2 selected cells on this test
+        verify(lockManager,
+               times(5)).acquireLock();
     }
 
     @Test
@@ -1319,6 +1342,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         verify(synchronizer,
                times(1)).deleteCell(rowRangeCaptor.capture(),
                                     columnIndexCaptor.capture());
+        // 3 rows created during the setup + 1 selected cell on this test
+        verify(lockManager,
+               times(4)).acquireLock();
 
         checkDTSelectionsChangedEventFired(2);
 
@@ -1337,20 +1363,23 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         final AttributeCol52 column = new AttributeCol52() {
 
             {
-                setAttribute(RuleAttributeWidget.ENABLED_ATTR);
+                setAttribute(Attribute.ENABLED.getAttributeName());
             }
         };
         dtPresenter.appendColumn(column);
 
         final GridData uiModel = dtPresenter.getUiModel();
         uiModel.selectCell(0,
-                           2);
+                           3);
 
         dtPresenter.onDeleteSelectedCells();
 
         verify(synchronizer,
                never()).deleteCell(any(GridData.Range.class),
                                    any(Integer.class));
+        // 3 rows created during the setup + 1 selected cell on this test
+        verify(lockManager,
+               times(4)).acquireLock();
         checkDTSelectionsChangedEventFired(1);
     }
 
@@ -1359,16 +1388,16 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         final AttributeCol52 column = new AttributeCol52() {
 
             {
-                setAttribute(RuleAttributeWidget.ENABLED_ATTR);
+                setAttribute(Attribute.ENABLED.getAttributeName());
             }
         };
         dtPresenter.appendColumn(column);
 
         final GridData uiModel = dtPresenter.getUiModel();
-        uiModel.selectCell(0,
-                           1);
         uiModel.selectCell(0,
                            2);
+        uiModel.selectCell(0,
+                           3);
 
         final ArgumentCaptor<Integer> columnIndexCaptor = ArgumentCaptor.forClass(Integer.class);
         final ArgumentCaptor<GridData.Range> rowRangeCaptor = ArgumentCaptor.forClass(GridData.Range.class);
@@ -1380,11 +1409,14 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
                                     columnIndexCaptor.capture());
         verify(synchronizer,
                never()).deleteCell(any(GridData.Range.class),
-                                   eq(2));
+                                   eq(3));
+        // 3 rows created during the setup + 2 selected cells on this test
+        verify(lockManager,
+               times(5)).acquireLock();
         checkDTSelectionsChangedEventFired(3);
 
         final GridCell<?> booleanCell = uiModel.getCell(0,
-                                                        2);
+                                                        3);
         assertNotNull(booleanCell);
         assertFalse((Boolean) booleanCell.getValue().getValue());
 
@@ -1394,7 +1426,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
                      rowRange.getMinRowIndex());
         assertEquals(0,
                      rowRange.getMaxRowIndex());
-        assertEquals(1,
+        assertEquals(2,
                      columnIndex.intValue());
     }
 
@@ -1412,18 +1444,21 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         final AttributeCol52 column = new AttributeCol52() {
 
             {
-                setAttribute("attribute1");
+                setAttribute(Attribute.SALIENCE.getAttributeName());
             }
         };
         dtPresenter.appendColumn(column);
         final GridData uiModel = dtPresenter.getUiModel();
         uiModel.selectCell(0,
-                           2);
+                           3);
 
         dtPresenter.onDeleteSelectedColumns();
 
         verify(synchronizer,
                times(1)).deleteColumn(eq(column));
+        // 3 rows created during the setup + 1 selected cell on this test
+        verify(lockManager,
+               times(4)).acquireLock();
         checkDTSelectionsChangedEventFired(2);
     }
 
@@ -1451,6 +1486,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
                times(1)).deleteRow(eq(1));
 
         checkDTSelectionsChangedEventFired(4);
+        // 3 rows created during the setup + 2 selected cells on this test
+        verify(lockManager,
+               times(5)).acquireLock();
     }
 
     @Test
@@ -1479,6 +1517,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
 
         verify(synchronizer,
                times(1)).insertRow(eq(0));
+        // 3 rows created during the setup + 1 selected cell on this test
+        verify(lockManager,
+               times(4)).acquireLock();
     }
 
     @Test
@@ -1493,6 +1534,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
 
         verify(synchronizer,
                never()).insertRow(any(Integer.class));
+        // 3 rows created during the setup + 2 selected cells on this test
+        verify(lockManager,
+               times(5)).acquireLock();
     }
 
     @Test
@@ -1513,6 +1557,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
 
         verify(synchronizer,
                times(1)).insertRow(eq(1));
+        // 3 rows created during the setup + 1 selected cell on this test
+        verify(lockManager,
+               times(4)).acquireLock();
     }
 
     @Test
@@ -1527,6 +1574,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
 
         verify(synchronizer,
                never()).insertRow(any(Integer.class));
+        // 3 rows created during the setup + 2 selected cells on this test
+        verify(lockManager,
+               times(5)).acquireLock();
     }
 
     @Test
@@ -1549,6 +1599,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         verify(synchronizer,
                times(1)).setCellOtherwiseState(eq(0),
                                                eq(0));
+        // 3 rows created during the setup + 1 selected cell on this test
+        verify(lockManager,
+               times(4)).acquireLock();
     }
 
     @Test
@@ -1564,6 +1617,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         verify(synchronizer,
                never()).setCellOtherwiseState(any(Integer.class),
                                               any(Integer.class));
+        // 3 rows created during the setup + 2 selected cells on this test
+        verify(lockManager,
+               times(5)).acquireLock();
     }
 
     @Test
