@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -20,6 +20,9 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 import java.util.Set;
+import java.util.stream.Collectors;
+
+import javax.annotation.PostConstruct;
 import javax.enterprise.context.ApplicationScoped;
 import javax.enterprise.event.Event;
 import javax.enterprise.inject.Instance;
@@ -28,8 +31,6 @@ import javax.inject.Named;
 
 import org.drools.workbench.models.commons.backend.rule.RuleModelDRLPersistenceImpl;
 import org.drools.workbench.models.commons.backend.rule.RuleModelIActionPersistenceExtension;
-import org.drools.workbench.models.datamodel.imports.Import;
-import org.drools.workbench.models.datamodel.oracle.PackageDataModelOracle;
 import org.drools.workbench.models.datamodel.rule.RuleModel;
 import org.drools.workbench.screens.guided.rule.model.GuidedEditorContent;
 import org.drools.workbench.screens.guided.rule.service.GuidedRuleEditorService;
@@ -44,12 +45,15 @@ import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.guvnor.common.services.shared.validation.model.ValidationMessage;
 import org.jboss.errai.bus.server.annotations.Service;
+import org.kie.soup.project.datamodel.imports.Import;
+import org.kie.soup.project.datamodel.oracle.PackageDataModelOracle;
 import org.kie.workbench.common.services.backend.service.KieService;
 import org.kie.workbench.common.services.datamodel.backend.server.DataModelOracleUtilities;
 import org.kie.workbench.common.services.datamodel.backend.server.service.DataModelService;
 import org.kie.workbench.common.services.datamodel.model.PackageDataModelOracleBaselinePayload;
 import org.uberfire.backend.server.util.Paths;
 import org.uberfire.backend.vfs.Path;
+import org.uberfire.ext.editor.commons.backend.service.SaveAndRenameServiceImpl;
 import org.uberfire.ext.editor.commons.service.CopyService;
 import org.uberfire.ext.editor.commons.service.DeleteService;
 import org.uberfire.ext.editor.commons.service.RenameService;
@@ -98,6 +102,9 @@ public class GuidedRuleEditorServiceImpl
     @Inject
     private CommentedOptionFactory commentedOptionFactory;
 
+    @Inject
+    private SaveAndRenameServiceImpl<RuleModel, Metadata> saveAndRenameService;
+
     private SafeSessionInfo safeSessionInfo;
 
     private Collection<RuleModelIActionPersistenceExtension> persistenceExtensions = new ArrayList<>();
@@ -113,13 +120,18 @@ public class GuidedRuleEditorServiceImpl
         persistenceExtensionInstance.forEach(persistenceExtensions::add);
     }
 
+    @PostConstruct
+    public void init() {
+        saveAndRenameService.init(this);
+    }
+
     @Override
     public Path create(final Path context,
                        final String fileName,
                        final RuleModel model,
                        final String comment) {
         try {
-            final Package pkg = projectService.resolvePackage(context);
+            final Package pkg = moduleService.resolvePackage(context);
             final String packageName = (pkg == null ? null : pkg.getPackageName());
             model.setPackageName(packageName);
 
@@ -191,6 +203,15 @@ public class GuidedRuleEditorServiceImpl
         //Get FQCN's used by Globals
         consumedFQCNs.addAll(oracle.getPackageGlobals().values());
 
+        //Get FQCN's of collections defined in project settings
+        //they can be used in From Collect expressions
+        consumedFQCNs.addAll(oracle.getModuleCollectionTypes()
+                                     .entrySet()
+                                     .stream()
+                                     .filter(entry -> entry.getValue())
+                                     .map(entry -> entry.getKey())
+                                     .collect(Collectors.toSet()));
+
         DataModelOracleUtilities.populateDataModel(oracle,
                                                    dataModel,
                                                    consumedFQCNs);
@@ -210,11 +231,10 @@ public class GuidedRuleEditorServiceImpl
                      final Metadata metadata,
                      final String comment) {
         try {
-            final Package pkg = projectService.resolvePackage(resource);
+            final Package pkg = moduleService.resolvePackage(resource);
             final String packageName = (pkg == null ? null : pkg.getPackageName());
             model.setPackageName(packageName);
 
-            Metadata currentMetadata = metadataService.getMetadata(resource);
             ioService.write(Paths.convert(resource),
                             toSourceUnexpanded(resource,
                                                model),
@@ -222,9 +242,6 @@ public class GuidedRuleEditorServiceImpl
                                                             metadata),
                             commentedOptionFactory.makeCommentedOption(comment));
 
-            fireMetadataSocialEvents(resource,
-                                     currentMetadata,
-                                     metadata);
             return resource;
         } catch (Exception e) {
             throw ExceptionUtilities.handleException(e);
@@ -324,4 +341,13 @@ public class GuidedRuleEditorServiceImpl
         final String source = RuleModelDRLPersistenceImpl.getInstance().marshal(model);
         return source;
     }
+
+    @Override
+    public Path saveAndRename(final Path path,
+                              final String newFileName,
+                              final Metadata metadata,
+                              final RuleModel content,
+                              final String comment) {
+        return saveAndRenameService.saveAndRename(path, newFileName, metadata, content, comment);
+    }
 }
