@@ -20,18 +20,23 @@ import java.util.List;
 import java.util.Optional;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
+import org.drools.scenariosimulation.api.model.FactIdentifier;
+import org.drools.scenariosimulation.api.model.FactMappingType;
+import org.drools.scenariosimulation.api.model.ScenarioSimulationModel;
 import org.drools.workbench.screens.scenariosimulation.client.commands.ScenarioSimulationContext;
-import org.drools.workbench.screens.scenariosimulation.client.utils.ScenarioSimulationBuilders;
+import org.drools.workbench.screens.scenariosimulation.client.enums.GridWidget;
+import org.drools.workbench.screens.scenariosimulation.client.factories.ScenarioCellTextAreaSingletonDOMElementFactory;
+import org.drools.workbench.screens.scenariosimulation.client.factories.ScenarioHeaderTextBoxSingletonDOMElementFactory;
 import org.drools.workbench.screens.scenariosimulation.client.widgets.ScenarioGridColumn;
-import org.drools.workbench.screens.scenariosimulation.model.FactIdentifier;
-import org.drools.workbench.screens.scenariosimulation.model.ScenarioSimulationModel;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.mockito.Mock;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 
-import static org.junit.Assert.assertTrue;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.COLUMN_INDEX;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.FULL_PACKAGE;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.VALUE_CLASS_NAME;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.atLeastOnce;
 import static org.mockito.Mockito.never;
@@ -41,7 +46,7 @@ import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
-public class SetInstanceHeaderCommandTest extends AbstractScenarioSimulationCommandTest {
+public class SetInstanceHeaderCommandTest extends AbstractScenarioGridCommandTest {
 
     @Mock
     private List<GridColumn<?>> mockGridColumns;
@@ -51,10 +56,10 @@ public class SetInstanceHeaderCommandTest extends AbstractScenarioSimulationComm
         super.setup();
         when(mockGridColumns.indexOf(gridColumnMock)).thenReturn(COLUMN_INDEX);
         when(scenarioGridModelMock.getColumns()).thenReturn(mockGridColumns);
-        command = spy(new SetInstanceHeaderCommand() {
+        commandSpy = spy(new SetInstanceHeaderCommand(GridWidget.SIMULATION) {
 
             @Override
-            protected ScenarioGridColumn getScenarioGridColumnLocal(ScenarioSimulationBuilders.HeaderBuilder headerBuilder, ScenarioSimulationContext context) {
+            protected ScenarioGridColumn getScenarioGridColumnLocal(String instanceTitle, String propertyTitle, String columnId, String columnGroup, FactMappingType factMappingType, ScenarioHeaderTextBoxSingletonDOMElementFactory factoryHeader, ScenarioCellTextAreaSingletonDOMElementFactory factoryCell, String placeHolder) {
                 return gridColumnMock;
             }
 
@@ -63,23 +68,22 @@ public class SetInstanceHeaderCommandTest extends AbstractScenarioSimulationComm
                 return Optional.empty();
             }
         });
-        assertTrue(command.isUndoable());
-        when(simulationDescriptorMock.getType()).thenReturn(ScenarioSimulationModel.Type.RULE);
+        settingsLocal.setType(ScenarioSimulationModel.Type.RULE);
     }
 
     @Test
     public void executeNoColumn() {
         gridColumnMock = null;
-        command.execute(scenarioSimulationContext);
-        verify((SetInstanceHeaderCommand) command, never()).executeIfSelectedColumn(scenarioSimulationContext, gridColumnMock);
+        commandSpy.execute(scenarioSimulationContextLocal);
+        verify((SetInstanceHeaderCommand) commandSpy, never()).executeIfSelectedColumn(scenarioSimulationContextLocal, gridColumnMock);
     }
 
     @Test
     public void executeDMN() {
-        scenarioSimulationContext.getStatus().setFullPackage(FULL_PACKAGE);
-        scenarioSimulationContext.getStatus().setClassName(VALUE_CLASS_NAME);
-        when(simulationDescriptorMock.getType()).thenReturn(ScenarioSimulationModel.Type.DMN);
-        command.execute(scenarioSimulationContext);
+        scenarioSimulationContextLocal.getStatus().setFullPackage(FULL_PACKAGE);
+        scenarioSimulationContextLocal.getStatus().setClassName(VALUE_CLASS_NAME);
+        settingsLocal.setType(ScenarioSimulationModel.Type.DMN);
+        commandSpy.execute(scenarioSimulationContextLocal);
         verify(gridColumnMock, times(1)).setEditableHeaders(eq(false));
         verify(gridColumnMock, atLeastOnce()).getInformationHeaderMetaData();
         verify(informationHeaderMetaDataMock, times(1)).setTitle(eq(VALUE_CLASS_NAME));
@@ -90,10 +94,10 @@ public class SetInstanceHeaderCommandTest extends AbstractScenarioSimulationComm
 
     @Test
     public void executeRULE() {
-        scenarioSimulationContext.getStatus().setFullPackage(FULL_PACKAGE);
-        scenarioSimulationContext.getStatus().setClassName(VALUE_CLASS_NAME);
-        when(simulationDescriptorMock.getType()).thenReturn(ScenarioSimulationModel.Type.RULE);
-        command.execute(scenarioSimulationContext);
+        scenarioSimulationContextLocal.getStatus().setFullPackage(FULL_PACKAGE);
+        scenarioSimulationContextLocal.getStatus().setClassName(VALUE_CLASS_NAME);
+        settingsLocal.setType(ScenarioSimulationModel.Type.RULE);
+        commandSpy.execute(scenarioSimulationContextLocal);
         verify(gridColumnMock, times(1)).setEditableHeaders(eq(true));
         verify(gridColumnMock, atLeastOnce()).getInformationHeaderMetaData();
         verify(informationHeaderMetaDataMock, times(1)).setTitle(eq(VALUE_CLASS_NAME));
